#!/usr/bin/env python
# -*- coding:utf-8 -*-
#
# Main class, parse args and send request
#
# Author: Kevin Hu


import os
import glob
from optparse import OptionParser

from urlrequest import RequestURL
from config import *


class Ubuntupaste():
    """
    Main class for Ubuntupaste script
    """

    # parse argument
    def parseargs(self):
        """
        parse argument, and return config
        param: list of argv except executable name
        return: config table containing
            typename -t
            open browser -b
        """
        usage = "Usage: <up> [OPTION]... FILENAME..."
        parser = OptionParser(usage = usage)
    
        # Add typename option
        parser.add_option("-t", "--type",
                          dest="type", help="specify type of target file")
    
        # Add open browser option
        parser.add_option("-b", "--browser",
                          action="store_true", dest="browser",
                          help="open response url in browser")
    
        return parser
    
    
    # Find type of the file
    def findtype(self, filename, suffix_match):
        """
        param: filename
        return: type string
        """
        if (filename.lower().startswith("makefile")):
            return "make"
    
        if (filename.lower() == "cmakelist.txt"):
            return "cmake"
    
        fs = filename.split(".")
        if len(fs) == 1:
            return "text"
    
        suffix = (fs[-1]).lower()
    
        if suffix not in suffix_match.keys():
            return "text"
    
        return suffix_match[suffix]
    
    
    # The main function
    def run(self):
        """
        The main function
        """
        # read options and args
        parser = self.parseargs()
        (options, args) = parser.parse_args()
        if (args == []):
            parser.print_help()
            exit()
    
        filetype = None
        if options.type:
            filetype = options.type
    
        # open and read in all files
        totalsize = 0
        allfiles = []
        for f in args:
            for g in glob.iglob(f):
                try:
                    allfiles.append( open(g, "r").read() )
                    totalsize += os.stat(g).st_size
    
                    # protector for file size
                    if totalsize > TOTALSIZE:
                        print("Over size limit, please send one at a time")
                        exit()
    
                    # protector for different file type
                    if not filetype:
                        filetype = self.findtype(g, SUFFIX)
    
                except Exception as e:
                    print(e)
                    print("Error opening file")
                    # protector if overall size too large
    
        # DEBUG
        # print(allfiles)
        # print(filetype)
        # print(totalsize)
    
        # send the request
        content = {"poster": os.environ["USER"],
                   "syntax": filetype,
                   "content": ('\n' * 8).join(allfiles)}
    
        req = RequestURL(content)
        resp = req.send()
    
        print(resp.url)
    
        # Option to open the browser
        if (resp.url != None):
            if (options.browser):
                try:
                    import webbrowser
                    webbrowser.open(resp.url)
                except Exception as e:
                    print(e)
                    print("Could not open browser. Please copy and paste in browser")
                    exit()
    
        




# -*- coding:utf-8 -*-
# 
# Defines Parser class. parse content
# from input file
#
# Author: Kevin Hu

class Parser():
    """
    Escape input file and parse unicode
    """
    def __init__():
        
        pass


    



# -*- coding:utf-8 -*-
# 
# This file defines the RequestURL class,
# which posts data to the server for response
#
# Author: Kevin Hu

import requests

REQUEST_URL = {"ubuntu": "http://paste.ubuntu.com"}

class RequestURL():
    """
    The class to send request url
    and receive response
    """
    def __init__(self, content, server="ubuntu"):
        """
        init function
        param: server - the server you choose
               content - the content data structure
        """
        if (server not in REQUEST_URL.keys()):
            print("No such service " + server)
            exit()

        self.server = REQUEST_URL[server]
        self.url = REQUEST_URL[server]
        self.content = content

       
    def send(self):
        """
        send request to server
        return: request object from server
        """
        try:
            self.resp = requests.post(self.server, data = self.content)
        except Exception as e:
            print(e)
            print("Error posting to the server, please try again later.")

        return self.resp


def test():
    """
    Testcase for urlrequest class
    """
    content = {"poster":"hello",
               "syntax":"python",
               "content":"import os\n\nos.listdir('.')\n"*100}

    req = RequestURL(content)
    resp = req.send()

    print (resp.url)

    if resp.history:
        for h in resp.history:
            print (h.url)


if __name__ == "__main__":
    test()



# -*- coding:utf-8 -*-
# 
#
# Author: Kevin Hu


TOTALSIZE = 4194304

SUFFIX = {"txt": "text",
         "sh":"bash",
         "asp": "asp", 
         "aspx": "asp",
         "sh": "bash",
         "bat": "bat",
         "c": "c", 
         "h": "c",
         "cs": "csharp",
         "cl": "common-lisp",
         "clj": "clojure",
         "cpp": "cpp",
         "s": "nasm",
         "cpp": "cpp", 
         "cc": "cpp",
         "css": "css", 
         "less": "css",
         "d": "d",
         "erl": "erlang",
         "el": "elisp",
         "f90": "fortran",
         "go": "go",
         "hs": "haskell",
         "html": "html", 
         "htm": "html",
         "ll": "llvm",
         "lua": "lua",
         "java": "java",
         "js": "javascript",
         "m": "objective-c",
         "ocaml": "ocaml",
         "py": "python",
         "pl": "perl",
         "ps": "postscript",
         "pro": "prolog",
         "rb": "ruby",
         "rst": "rst",
         "sch": "scheme",
         "sql": "sql",
         "sass": "css", 
         "scala": "scala",
         "scss": "scss",
         "tcl": "tcl",
         "tex": "tex",
         "v": "verilog",
         "xml": "xml",
         "xslt": "xslt",
         "yml": "yaml",
         "yaml": "yaml"}



#!/usr/bin/env python
# -*- coding:utf-8 -*-
#
# Setup.py
#
# Author: Kevin Hu

from setuptools import setup

setup(name = "UbuntuPaste",
      version = "0.0.1",
      description = "A gadget to paste file to UbuntuPaste from cli",
      author = "Kevin Hu",
      author_email = "hxy9243@gmail.com",
      keywords = "ubuntu pastebin",
      url = "https://github.com/hxy9243/UbuntuPaste",
      packages = ["ubuntupaste"],
      package_dir = {"ubuntupaste": "ubuntupaste"},
      scripts = ["bin/up"],
      platforms = ["Linux"],
      classifiers = ["Development Status :: 3 - Alpha",
                     "Topic :: Utilities",
                     "Environment :: Console",
                     "License :: OSI Approved :: GNU Lesser General Public License v2 (LGPLv2)"
                    ]
)
